@@ -15,9 +15,12 @@
         nCrn <- nCrn-1
     }
     if(nCrn > 1) layout(matrix(1:nCrn, nrow=nCrn, ncol=1))
+    text.years <- gettext("Years", domain="R-dplR")
+    text.rwi <- gettext("RWI", domain="R-dplR")
+    text.samp <- gettext("Sample Depth", domain="R-dplR")
     for(i in inc(1, nCrn)){
-        plot(yr.vec, crn[, i], type="l", xlab="Years", ylab="RWI",
-             main=crn.names[i], ...)
+        plot(yr.vec, crn[, i], type="l",
+             xlab=text.years, ylab=text.rwi, main=crn.names[i], ...)
         spl <- crn[, i]
         tmp <- na.omit(spl)
         ## Only possibly NULL in the first round of the for loop
@@ -30,7 +33,7 @@
             plot(yr.vec, samp.depth, type="l", lty="dashed",
                  xlab="", ylab="", axes=FALSE)
             axis(4, at=pretty(samp.depth))
-            mtext("Sample Depth", side=4, line=1.25)
+            mtext(text.samp, side=4, line=1.25)
         }
     }
 }
