@@ -2,8 +2,10 @@
                         pos.slope = FALSE)
 {
     out <- rwl
-    for(i in 1:ncol(rwl)){
-        cat("Detrend series ", i, "of ", ncol(rwl), "\n")
+    n.col <- ncol(rwl)
+    fmt <- gettext("Detrend series %d of %d\n", domain="R-dplR")
+    for(i in 1:n.col){
+        cat(sprintf(fmt, i, n.col))
         fits <- i.detrend.series(rwl[, i], y.name=y.name[i], nyrs = nyrs,
                                  f = f, pos.slope = pos.slope)
         out[, i] <- fits
