@@ -17,7 +17,7 @@
     } else{
         ## Make error checks here
         if(nrow(ids) != n.cores)
-            stop("dimension problem: 'ncol(rwi)' and 'nrow(ids)' are unequal")
+            stop("dimension problem: ", "'ncol(rwi)' != 'nrow(ids)'")
         if(!all(sapply(ids, is.numeric)))
             stop("'ids' must have numeric columns")
     }
