@@ -3,7 +3,7 @@ function(rwl, ...)
 {
   yr <- as.numeric(rownames(rwl))
   segs <- rwl
-  first.year <- apply(segs, 2, yr.range)[1, ]
+  first.year <- apply(segs, 2, yr.range, yr.vec=yr)[1, ]
   neworder <- sort(first.year, decreasing=FALSE)
   segs <- segs[, names(neworder), drop=FALSE]
   for(i in 1:ncol(segs)){
@@ -13,7 +13,7 @@ function(rwl, ...)
   on.exit(par(op))         # Reset par on exit
   par(mar=c(4,5,2,2) + 0.1, mgp=c(1.25,0.25,0), tcl=0.25)
   plot(yr, segs[,1], type="n", ylim=c(0,ncol(segs)), axes=FALSE,
-       ylab="", xlab="Year", ...)
+       ylab="", xlab=gettext("Year", domain="R-dplR"), ...)
   apply(segs, 2, lines, x=yr, lwd=2)
   axis(2, at=1:ncol(segs), labels=colnames(segs), srt=45, tick=FALSE, las=2)
   axis(1)
